<?php
/**
 * draft functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package draft-portfolio
 */

if ( ! function_exists( 'draft_portfolio_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function draft_portfolio_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on draft, use a find and replace
	 * to change 'draft-portfolio' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'draft-portfolio', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	
	// Thumbnail sizes

		add_image_size( 'draft-portfolio-thumb-large', 700, 450 );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'draft-portfolio' ),
		'footer' => esc_html__( 'Footer Menu', 'draft-portfolio' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'draft_portfolio_custom_background_args', array(
		'default-color' => 'f0f0f0',
		'default-image' => '',
	) ) );
}
endif; // draft_portfolio_setup
add_action( 'after_setup_theme', 'draft_portfolio_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function draft_portfolio_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'draft_portfolio_content_width', 960 );
}
add_action( 'after_setup_theme', 'draft_portfolio_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function draft_portfolio_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'draft-portfolio' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'draft_portfolio_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function draft_portfolio_custom_font() {
	$query_args = array(
		'family' => 'Crimson+Text:400,700|Montserrat:700',
		'subset' => 'latin,latin-ext',
	);
	wp_register_style( 'draft_portfolio_custom_font', add_query_arg( $query_args, "//fonts.googleapis.com/css" ), array(), null );
            }
            
add_action('wp_enqueue_scripts', 'draft_portfolio_custom_font');

function draft_portfolio_scripts() {
	wp_enqueue_style( 'draft-style', get_stylesheet_uri() );

	wp_enqueue_style( 'draft-grid', get_template_directory_uri() . '/css/grid.css' );

	wp_enqueue_style( 'draft-menu', get_template_directory_uri() . '/css/mobilemenu.css' );

	wp_enqueue_style( 'draft-icons', get_template_directory_uri() . '/css/css/font-awesome.min.css' );

	wp_enqueue_script( 'jquery');
	wp_enqueue_script( 'jquery-masonry');	

	wp_enqueue_script( 'draft-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'draft-mobilemenu', get_template_directory_uri() . '/js/slickmenu.js', array(), '20170206', true );

	wp_enqueue_script( 'draft-script', get_template_directory_uri() . '/js/scripts.js', array(), '20170203', true );


	wp_enqueue_script( 'draft-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'draft_portfolio_scripts' );

/**
 * Implement the Custom Header feature.
 */

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

function draft_portfolio_upgrade_notice(){
    echo '<div class="notice notice-success is-dismissible">
       <p><b>Add a Portfolio Plugin, Logo, Customisation & more layout options, and get 24/7 email support, for just $39 (code: wporg for 20% Off Today)  <a target="_blank" href="https://thepixeltribe.com/draft_portfolio/free-wordpress-portfolio-theme/">Upgrade to PRO Today</a>.</b></p>
    </div>';
}
add_action('admin_notices', 'draft_portfolio_upgrade_notice');